git.lucas.co / cce-ui
GPU-accelerated UI toolkit (Vulkan)
git clone https://git.lucas.co/cce-ui.git

commitf0c8bfeb0d2d71f481e9af96b3d6e8bc8b4acfdc
parent5ac6362672
authorLucas Galante <[email protected]>
date2026-08-25 10:37
graph: the designer's meta (per-node preferences) node has no geometry toggle

 src/widget/display/graph.rs | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/src/widget/display/graph.rs b/src/widget/display/graph.rs
index 42ab0f1..de2d8df 100644
--- a/src/widget/display/graph.rs
+++ b/src/widget/display/graph.rs
@@ -238,8 +238,9 @@ impl Graph {
     pub fn toggle_rect(&self, idx: usize) -> Option<(f32, f32, f32, f32)> {
         if let Some(node) = self.nodes.get(idx) {
             // Settings containers have no geometry to toggle: utility nodes,
-            // and the designer's session node that now nests them.
-            if node.node_type == "utility" || node.node_type == "session" {
+            // the designer's session node that now nests them, and the
+            // per-node meta (preferences) node.
+            if node.node_type == "utility" || node.node_type == "session" || node.node_type == "meta" {
                 return None;
             }
         }